@@ -570,7 +570,7 @@ new_period <- function(x = numeric(), interval) {
 
 get_interval_number <- function(x) {
   if (!grepl("^\\d", x)) return(1L)
-  as.integer(gsub("^(\\d*).+$", "\\1", x))
+  as.integer(gsub("^(\\d*).*$", "\\1", x))
 }
 
 
